import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ChannelVideoService } from '../../service/channel/channelVideo.service';
import {
  CDTO_channelVideo,
  CVO_channelVideo,
  FVO_channelVideo,
  QDTO_channelVideo,
  QVO_channelVideo,
  UDTO_channelVideo,
  UVAO_channelVideo,
} from '../../interface/channel/channelVideo.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技频道-展会视频'])
@Controller('/channelVideo')
export class ChannelVideoController extends BaseController {
  @Inject()
  service: ChannelVideoService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_channelVideo })
  async create(@Body() data: CDTO_channelVideo) {
    const dbData = await this.service.create(data);
    const result = new CVO_channelVideo(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_channelVideo })
  async query(
    @Query() filter: QDTO_channelVideo,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_channelVideo(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_channelVideo })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_channelVideo(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_channelVideo })
  async update(@Param('id') id: string, @Body() body: UDTO_channelVideo) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
