import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { NewsColumnService } from '../../service/news/newsColumn.service';
import {
  CDTO_newsColumn,
  CVO_newsColumn,
  FVO_newsColumn,
  QDTO_newsColumn,
  QVO_newsColumn,
  UDTO_newsColumn,
  UVAO_newsColumn,
} from '../../interface/news/newsColumn.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['栏目管理'])
@Controller('/newsColumn')
export class NewsColumnController extends BaseController {
  @Inject()
  service: NewsColumnService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_newsColumn })
  async create(@Body() data: CDTO_newsColumn) {
    const dbData = await this.service.create(data);
    const result = new CVO_newsColumn(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_newsColumn })
  async query(
    @Query() filter: QDTO_newsColumn,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_newsColumn(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_newsColumn })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_newsColumn(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_newsColumn })
  async update(@Param('id') id: string, @Body() body: UDTO_newsColumn) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
