import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { NewsMessService } from '../../service/news/newsMess.service';
import {
  CDTO_newsMess,
  CVO_newsMess,
  FVO_newsMess,
  QDTO_newsMess,
  QVO_newsMess,
  UDTO_newsMess,
  UVAO_newsMess,
} from '../../interface/news/newsMess.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['信息管理'])
@Controller('/newsMess')
export class NewsMessController extends BaseController {
  @Inject()
  service: NewsMessService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_newsMess })
  async create(@Body() data: CDTO_newsMess) {
    const dbData = await this.service.create(data);
    const result = new CVO_newsMess(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_newsMess })
  async query(
    @Query() filter: QDTO_newsMess,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_newsMess(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_newsMess })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_newsMess(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_newsMess })
  async update(@Param('id') id: string, @Body() body: UDTO_newsMess) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
