import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PersonChatService } from '../../service/product/personChat.service';
import {
  CDTO_personChat,
  CVO_personChat,
  FVO_personChat,
  QDTO_personChat,
  QVO_personChat,
  UDTO_personChat,
  UVAO_personChat,
} from '../../interface/product/personChat.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['个人聊天表'])
@Controller('/personChat')
export class PersonChatController extends BaseController {
  @Inject()
  service: PersonChatService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_personChat })
  async create(@Body() data: CDTO_personChat) {
    const dbData = await this.service.create(data);
    await this.service.afterCreate(dbData);
    const result = new CVO_personChat(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_personChat })
  async query(
    @Query() filter: QDTO_personChat,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_personChat(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_personChat })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_personChat(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_personChat })
  async update(@Param('id') id: string, @Body() body: UDTO_personChat) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
