import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { PersonRoomService } from '../../service/product/personRoom.service';
import {
  CDTO_personRoom,
  CVO_personRoom,
  FVO_personRoom,
  // QDTO_personRoom,
  QVO_personRoom,
  UDTO_personRoom,
  UVAO_personRoom,
} from '../../interface/product/personRoom.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['个人聊天房间表'])
@Controller('/personRoom')
export class PersonRoomController extends BaseController {
  @Inject()
  service: PersonRoomService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_personRoom })
  async create(@Body() data: CDTO_personRoom) {
    const dbData = await this.service.create(data);
    const result = new CVO_personRoom(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_personRoom })
  async query(@Query() filter: any) {
    const list = await this.service.beforeQuery(filter);
    const data = [];
    for (const i of list.data) {
      const newData = new QVO_personRoom(i);
      data.push(newData);
    }
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_personRoom })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_personRoom(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_personRoom })
  async update(@Param('id') id: string, @Body() body: UDTO_personRoom) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
