import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ProjectInfoService } from '../../service/project/projectInfo.service';
import {
  CDTO_projectInfo,
  CVO_projectInfo,
  FVO_projectInfo,
  QDTO_projectInfo,
  QVO_projectInfo,
  UDTO_projectInfo,
  UVAO_projectInfo,
} from '../../interface/project/projectInfo.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['项目征集信息'])
@Controller('/projectInfo')
export class ProjectInfoController extends BaseController {
  @Inject()
  service: ProjectInfoService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_projectInfo })
  async create(@Body() data: CDTO_projectInfo) {
    const dbData = await this.service.create(data);
    const result = new CVO_projectInfo(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_projectInfo })
  async query(
    @Query() filter: QDTO_projectInfo,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_projectInfo(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_projectInfo })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_projectInfo(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_projectInfo })
  async update(@Param('id') id: string, @Body() body: UDTO_projectInfo) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
