import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ProjectNoticeService } from '../../service/project/projectNotice.service';
import {
  CDTO_projectNotice,
  CVO_projectNotice,
  FVO_projectNotice,
  QDTO_projectNotice,
  QVO_projectNotice,
  UDTO_projectNotice,
  UVAO_projectNotice,
} from '../../interface/project/projectNotice.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['项目征集通知'])
@Controller('/projectNotice')
export class ProjectNoticeController extends BaseController {
  @Inject()
  service: ProjectNoticeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_projectNotice })
  async create(@Body() data: CDTO_projectNotice) {
    const dbData = await this.service.create(data);
    const result = new CVO_projectNotice(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_projectNotice })
  async query(
    @Query() filter: QDTO_projectNotice,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_projectNotice(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_projectNotice })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_projectNotice(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_projectNotice })
  async update(@Param('id') id: string, @Body() body: UDTO_projectNotice) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
