import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SubscribeOrderService } from '../../service/subscribe/subscribeOrder.service';
import {
  CDTO_subscribeOrder,
  CVO_subscribeOrder,
  FVO_subscribeOrder,
  QDTO_subscribeOrder,
  QVO_subscribeOrder,
  UDTO_subscribeOrder,
  UVAO_subscribeOrder,
} from '../../interface/subscribe/subscribeOrder.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['预约服务订单'])
@Controller('/subscribeOrder')
export class SubscribeOrderController extends BaseController {
  @Inject()
  service: SubscribeOrderService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_subscribeOrder })
  async create(@Body() data: CDTO_subscribeOrder) {
    const dbData = await this.service.create(data);
    const result = new CVO_subscribeOrder(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_subscribeOrder })
  async query(
    @Query() filter: QDTO_subscribeOrder,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_subscribeOrder(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_subscribeOrder })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_subscribeOrder(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_subscribeOrder })
  async update(@Param('id') id: string, @Body() body: UDTO_subscribeOrder) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
