import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { SubscribeOrganService } from '../../service/subscribe/subscribeOrgan.service';
import {
  CDTO_subscribeOrgan,
  CVO_subscribeOrgan,
  FVO_subscribeOrgan,
  QDTO_subscribeOrgan,
  QVO_subscribeOrgan,
  UDTO_subscribeOrgan,
  UVAO_subscribeOrgan,
} from '../../interface/subscribe/subscribeOrgan.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['预约服务机构'])
@Controller('/subscribeOrgan')
export class SubscribeOrganController extends BaseController {
  @Inject()
  service: SubscribeOrganService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_subscribeOrgan })
  async create(@Body() data: CDTO_subscribeOrgan) {
    const dbData = await this.service.create(data);
    const result = new CVO_subscribeOrgan(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_subscribeOrgan })
  async query(
    @Query() filter: QDTO_subscribeOrgan,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_subscribeOrgan(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_subscribeOrgan })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_subscribeOrgan(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_subscribeOrgan })
  async update(@Param('id') id: string, @Body() body: UDTO_subscribeOrgan) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
