import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import {
  BaseController,
  FrameworkErrorEnum,
  SearchBase,
  ServiceError,
} from 'free-midway-component';
import { RoleService } from '../../service/system/role.service';
import { ModuleService } from '../../service/system/module.service';
import { MenusService } from '../../service/system/menus.service';
import { AdminService } from '../../service/user/admin.service';
import { CompanyService } from '../../service/user/company.service';
import { ExpertService } from '../../service/user/expert.service';
import { PersonalService } from '../../service/user/personal.service';
import { DockService } from '../../service/technology/dock.service';
import { TrainService } from '../../service/train/train.service';
import { ChannelService } from '../../service/channel/channel.service';
import {
  CDTO_role,
  CVO_role,
  FVO_role,
  QDTO_role,
  QVO_role,
  UDTO_role,
  UVAO_role,
} from '../../interface/system/role.interface';
import {
  ApiOperation,
  ApiQuery,
  ApiResponse,
  ApiTags,
} from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import get = require('lodash/get');
@ApiTags(['角色'])
@Controller('/role')
export class RoleController extends BaseController {
  @Inject()
  service: RoleService;

  @Inject()
  moduleService: ModuleService;

  @Inject()
  menusService: MenusService;

  @Inject()
  adminService: AdminService;

  @Inject()
  companyService: CompanyService;

  @Inject()
  expertService: ExpertService;

  @Inject()
  personalService: PersonalService;

  @Inject()
  dockService: DockService;

  @Inject()
  channelService: ChannelService;

  @Inject()
  trainService: TrainService;

  @Get('/um')
  @ApiOperation({ description: '获取用户的菜单' })
  async userMenu() {
    const user = this.ctx.user;
    if (!user)
      throw new ServiceError('用户未登录', FrameworkErrorEnum.NOT_LOGIN);
    const type = get(user, 'type');
    const user_id = get(user, '_id');
    let udata = {};
    if (type === '0' || type === '1' || type === '2' || type === '3')
      udata = await this.adminService.fetch(user_id);
    else if (type === '4') udata = await this.personalService.fetch(user_id);
    else if (type === '5') udata = await this.companyService.fetch(user_id);
    else if (type === '6') udata = await this.expertService.fetch(user_id);
    else if (type === '7') udata = await this.dockService.fetch(user_id);
    else if (type === '8') udata = await this.channelService.fetch(user_id);
    else if (type === '9') udata = await this.trainService.fetch(user_id);
    else if (type === '11') udata = await this.service.achieveInfo(user_id);
    const menus = await this.service.getMenuByRoles(get(udata, 'role', []));
    return menus;
  }
  @Get('/am')
  @ApiOperation({ description: '获取所有菜单提供选择' })
  async roleAllMenu() {
    const f = new SearchBase({});
    const moduleList = await this.moduleService.query(f, null, { lean: true });
    const result = [];
    for (const i of moduleList) {
      const menus = await this.menusService.queryMenu(i._id);
      const obj: any = { _id: i._id, name: i.name };
      if (menus.length > 0) obj.children = menus;
      result.push(obj);
    }
    return result;
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_role })
  async create(@Body() data: CDTO_role) {
    const dbData = await this.service.create(data);
    const result = new CVO_role(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_role })
  async query(
    @Query() filter: QDTO_role,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_role(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_role })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_role(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_role })
  async update(@Param('id') id: string, @Body() body: UDTO_role) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
