import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockChatService } from '../../service/technology/dockChat.service';
import {
  CDTO_dockChat,
  CVO_dockChat,
  FVO_dockChat,
  QDTO_dockChat,
  QVO_dockChat,
  UDTO_dockChat,
  UVAO_dockChat,
} from '../../interface/technology/dockChat.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-公共聊天'])
@Controller('/dockChat')
export class DockChatController extends BaseController {
  @Inject()
  service: DockChatService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockChat })
  async create(@Body() data: CDTO_dockChat) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockChat(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockChat })
  async query(
    @Query() filter: QDTO_dockChat,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockChat(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockChat })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockChat(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockChat })
  async update(@Param('id') id: string, @Body() body: UDTO_dockChat) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
