import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockExpertService } from '../../service/technology/dockExpert.service';
import {
  CDTO_dockExpert,
  CVO_dockExpert,
  FVO_dockExpert,
  QDTO_dockExpert,
  QVO_dockExpert,
  UDTO_dockExpert,
  UVAO_dockExpert,
} from '../../interface/technology/dockExpert.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-专家'])
@Controller('/dockExpert')
export class DockExpertController extends BaseController {
  @Inject()
  service: DockExpertService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockExpert })
  async create(@Body() data: CDTO_dockExpert) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockExpert(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockExpert })
  async query(
    @Query() filter: QDTO_dockExpert,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockExpert(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockExpert })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockExpert(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockExpert })
  async update(@Param('id') id: string, @Body() body: UDTO_dockExpert) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
