import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockImgtxtService } from '../../service/technology/dockImgtxt.service';
import {
  CDTO_dockImgtxt,
  CVO_dockImgtxt,
  FVO_dockImgtxt,
  QDTO_dockImgtxt,
  QVO_dockImgtxt,
  UDTO_dockImgtxt,
  UVAO_dockImgtxt,
} from '../../interface/technology/dockImgtxt.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-展会图文'])
@Controller('/dockImgtxt')
export class DockImgtxtController extends BaseController {
  @Inject()
  service: DockImgtxtService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockImgtxt })
  async create(@Body() data: CDTO_dockImgtxt) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockImgtxt(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockImgtxt })
  async query(
    @Query() filter: QDTO_dockImgtxt,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockImgtxt(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockImgtxt })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockImgtxt(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockImgtxt })
  async update(@Param('id') id: string, @Body() body: UDTO_dockImgtxt) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
