import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockJbftService } from '../../service/technology/dockJbft.service';
import {
  CDTO_dockJbft,
  CVO_dockJbft,
  FVO_dockJbft,
  QDTO_dockJbft,
  QVO_dockJbft,
  UDTO_dockJbft,
  UVAO_dockJbft,
} from '../../interface/technology/dockJbft.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-嘉宾访谈'])
@Controller('/dockJbft')
export class DockJbftController extends BaseController {
  @Inject()
  service: DockJbftService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockJbft })
  async create(@Body() data: CDTO_dockJbft) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockJbft(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockJbft })
  async query(
    @Query() filter: QDTO_dockJbft,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockJbft(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockJbft })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockJbft(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockJbft })
  async update(@Param('id') id: string, @Body() body: UDTO_dockJbft) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
