import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockTransService } from '../../service/technology/dockTrans.service';
import {
  CDTO_dockTrans,
  CVO_dockTrans,
  FVO_dockTrans,
  QVO_dockTrans,
  UDTO_dockTrans,
  UVAO_dockTrans,
} from '../../interface/technology/dockTrans.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-交易'])
@Controller('/dockTrans')
export class DockTransController extends BaseController {
  @Inject()
  service: DockTransService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockTrans })
  async create(@Body() data: CDTO_dockTrans) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockTrans(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockTrans })
  async query(@Query() filter: any) {
    const list = await this.service.beforeQuery(filter);
    const data = [];
    for (const i of list.data) {
      const newData = new QVO_dockTrans(i);
      data.push(newData);
    }
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockTrans })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockTrans(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockTrans })
  async update(@Param('id') id: string, @Body() body: UDTO_dockTrans) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
