import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockUserService } from '../../service/technology/dockUser.service';
import {
  CDTO_dockUser,
  CVO_dockUser,
  FVO_dockUser,
  QDTO_dockUser,
  QVO_dockUser,
  UDTO_dockUser,
  UVAO_dockUser,
  CDTO_userCheck,
} from '../../interface/technology/dockUser.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-申请用户'])
@Controller('/dockUser')
export class DockUserController extends BaseController {
  @Inject()
  service: DockUserService;

  @Get('/getProductListByDockId')
  async getUserList(@Query() filter: any) {
    const data = await this.service.getProductListByDockId(filter);
    return data;
  }
  @Post('goodCheck/:id')
  @Validate()
  async goodCheck(@Param('id') id: string, @Body() body: CDTO_userCheck) {
    const result = await this.service.goodCheck(id, body);
    return result;
  }
  @Post('userCheck/:id')
  @Validate()
  async userCheck(@Param('id') id: string, @Body() status: string) {
    const result = await this.service.userCheck(id, status);
    return result;
  }
  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockUser })
  async create(@Body() data: CDTO_dockUser) {
    // const body = await this.service.beforeCreate(data);
    const dbData = await this.service.create(data);
    const result = new CVO_dockUser(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockUser })
  async query(
    @Query() filter: QDTO_dockUser,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockUser(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockUser })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockUser(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockUser })
  async update(@Param('id') id: string, @Body() body: UDTO_dockUser) {
    // const list = await this.service.beforeUpdate(id, body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
