import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockVideoService } from '../../service/technology/dockVideo.service';
import {
  CDTO_dockVideo,
  CVO_dockVideo,
  FVO_dockVideo,
  QDTO_dockVideo,
  QVO_dockVideo,
  UDTO_dockVideo,
  UVAO_dockVideo,
} from '../../interface/technology/dockVideo.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-展会视频'])
@Controller('/dockVideo')
export class DockVideoController extends BaseController {
  @Inject()
  service: DockVideoService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockVideo })
  async create(@Body() data: CDTO_dockVideo) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockVideo(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockVideo })
  async query(
    @Query() filter: QDTO_dockVideo,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockVideo(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockVideo })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockVideo(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockVideo })
  async update(@Param('id') id: string, @Body() body: UDTO_dockVideo) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
