import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DockXmlyService } from '../../service/technology/dockXmly.service';
import {
  CDTO_dockXmly,
  CVO_dockXmly,
  FVO_dockXmly,
  QDTO_dockXmly,
  QVO_dockXmly,
  UDTO_dockXmly,
  UVAO_dockXmly,
} from '../../interface/technology/dockXmly.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['科技成果-项目路演'])
@Controller('/dockXmly')
export class DockXmlyController extends BaseController {
  @Inject()
  service: DockXmlyService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dockXmly })
  async create(@Body() data: CDTO_dockXmly) {
    const dbData = await this.service.create(data);
    const result = new CVO_dockXmly(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dockXmly })
  async query(
    @Query() filter: QDTO_dockXmly,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_dockXmly(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dockXmly })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dockXmly(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dockXmly })
  async update(@Param('id') id: string, @Body() body: UDTO_dockXmly) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
