import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TrainChatService } from '../../service/train/trainChat.service';
import {
  CDTO_trainChat,
  CVO_trainChat,
  FVO_trainChat,
  QDTO_trainChat,
  QVO_trainChat,
  UDTO_trainChat,
  UVAO_trainChat,
} from '../../interface/train/trainChat.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['培训问诊-公开聊天'])
@Controller('/trainChat')
export class TrainChatController extends BaseController {
  @Inject()
  service: TrainChatService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_trainChat })
  async create(@Body() data: CDTO_trainChat) {
    const dbData = await this.service.create(data);
    const result = new CVO_trainChat(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_trainChat })
  async query(
    @Query() filter: QDTO_trainChat,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_trainChat(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_trainChat })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_trainChat(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_trainChat })
  async update(@Param('id') id: string, @Body() body: UDTO_trainChat) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
