import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TrainVideoService } from '../../service/train/trainVideo.service';
import {
  CDTO_trainVideo,
  CVO_trainVideo,
  FVO_trainVideo,
  QDTO_trainVideo,
  QVO_trainVideo,
  UDTO_trainVideo,
  UVAO_trainVideo,
} from '../../interface/train/trainVideo.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['培训问诊-展会视频'])
@Controller('/trainVideo')
export class TrainVideoController extends BaseController {
  @Inject()
  service: TrainVideoService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_trainVideo })
  async create(@Body() data: CDTO_trainVideo) {
    const dbData = await this.service.create(data);
    const result = new CVO_trainVideo(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_trainVideo })
  async query(
    @Query() filter: QDTO_trainVideo,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_trainVideo(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_trainVideo })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_trainVideo(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_trainVideo })
  async update(@Param('id') id: string, @Body() body: UDTO_trainVideo) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
