import {
  Body,
  Config,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import {
  BaseController,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { AdminService } from '../../service/user/admin.service';
import {
  CDTO_admin,
  CVO_admin,
  FVO_admin,
  QDTO_admin,
  QVO_admin,
  UDTO_admin,
  UVAO_admin,
  LoginDTO,
  ResetPasswordDTO,
  LoginVO,
} from '../../interface/user/admin.interface';
import {
  ApiOperation,
  ApiQuery,
  ApiResponse,
  ApiTags,
} from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { JwtService } from '@midwayjs/jwt';
// import get = require('lodash/get');
// import lowerCase = require('lodash/lowerCase');
// import { RegisterCanNotIncludes } from '../../util/util';
import { UserUtilService } from '../../service/util/user.util';
import { UtilService } from '../../service/util/util';
@ApiTags(['管理员表'])
@Controller('/admin')
export class AdminController extends BaseController {
  @Inject()
  service: AdminService;

  @Inject()
  jwtService: JwtService;

  @Config('jwt.secret')
  jwtSecret;

  @Config('jwt.expiresIn')
  jwtExpiresIn;

  @Inject()
  userUtil: UserUtilService;

  @Inject()
  util: UtilService;

  @Post('/login')
  @Validate()
  async login(@Body() body: LoginDTO) {
    const data = await this.service.findUserToLogin(body);
    let vo = new LoginVO(data);
    vo = JSON.parse(JSON.stringify(vo));
    const token = await this.jwtService.sign(vo, this.jwtSecret, {
      expiresIn: this.jwtExpiresIn,
    });
    return token;
  }

  @Post('/rp')
  @ApiOperation({ description: '修改密码' })
  async resetPassword(@Body() body: ResetPasswordDTO) {
    if (!body.id)
      throw new ServiceError('未找到用户信息', FrameworkErrorEnum.NOT_LOGIN);
    // 查询用户
    const user = await this.service.fetch(body.id);
    if (!user)
      throw new ServiceError('未找到用户', FrameworkErrorEnum.NOT_FOUND_DATA);
    // 修改密码
    await this.service.updateOne(body.id, { password: body.password });
    // 返回结果
    return 'ok';
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_admin })
  async create(@Body() data: CDTO_admin) {
    // 检查是否含有不允许字符
    // const haveInvalid = RegisterCanNotIncludes.find(f =>
    //   lowerCase(data.account).includes(f)
    // );
    // if (haveInvalid)
    //   throw new ServiceError(
    //     `不允许包含特殊字符: ${RegisterCanNotIncludes.join('; ')}`
    //   );
    // 检查手机号和上级id
    // await this.userUtil.checkPhoneAndPid(data);
    const dbData = await this.service.create(data);
    const result = new CVO_admin(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_admin })
  async query(
    @Query() filter: QDTO_admin,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    // filter = this.util.turnDateRangeQuery(this.util.turnFilter(filter));
    let query: any = {};
    if (this.ctx.user) {
      query = await this.service.dealQueryCondition(filter);
    } else {
      query = filter;
    }
    const list = await this.service.query(query, {
      skip,
      limit,
      sort: { 'meta.createdAt': -1 },
    });
    const data = [];
    for (const i of list) {
      const newData = new QVO_admin(i);
      data.push(newData);
    }
    const total = await this.service.count(query);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_admin })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_admin(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_admin })
  async update(@Param('id') id: string, @Body() body: UDTO_admin) {
    // 检查手机号和上级id
    // await this.userUtil.checkUpdateCardAndPid(id, body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
