import {
  Body,
  Config,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import {
  BaseController,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { ExpertService } from '../../service/user/expert.service';
import {
  CDTO_expert,
  CVO_expert,
  FVO_expert,
  QDTO_expert,
  QVO_expert,
  UDTO_expert,
  UVAO_expert,
  LoginDTO,
  LoginVO,
  ResetPasswordDTO,
} from '../../interface/user/expert.interface';
import {
  ApiOperation,
  ApiQuery,
  ApiResponse,
  ApiTags,
} from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UserUtilService } from '../../service/util/user.util';
import { JwtService } from '@midwayjs/jwt';
import { UtilService } from '../../service/util/util';
import get = require('lodash/get');
@ApiTags(['专家用户'])
@Controller('/expert')
export class ExpertController extends BaseController {
  @Inject()
  service: ExpertService;

  @Inject()
  userUtil: UserUtilService;

  @Inject()
  jwtService: JwtService;

  @Config('jwt.secret')
  jwtSecret;

  @Config('jwt.expiresIn')
  jwtExpiresIn;

  @Inject()
  util: UtilService;

  @Post('/login')
  @Validate()
  async login(@Body() body: LoginDTO) {
    const data = await this.service.findUserToLogin(body);
    let vo = new LoginVO(data);
    vo = JSON.parse(JSON.stringify(vo));
    const token = await this.jwtService.sign(vo, this.jwtSecret, {
      expiresIn: this.jwtExpiresIn,
    });
    return token;
  }

  @Post('/rp')
  @ApiOperation({ description: '修改密码' })
  async resetPassword(@Body() body: ResetPasswordDTO) {
    // 获取用户token中的登录信息
    const user_id = get(this.ctx, 'user._id');
    if (!user_id)
      throw new ServiceError('未找到用户信息', FrameworkErrorEnum.NOT_LOGIN);
    // 查询用户
    const user = await this.service.fetch(user_id);
    if (!user)
      throw new ServiceError('未找到用户', FrameworkErrorEnum.NOT_FOUND_DATA);
    // 修改密码
    await this.service.updateOne(user_id, body);
    // 返回结果
    return 'ok';
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_expert })
  async create(@Body() data: CDTO_expert) {
    // 检查手机号
    // await this.userUtil.checkPhoneAndPid(data);
    const dbData = await this.service.create(data);
    const result = new CVO_expert(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_expert })
  async query(
    @Query() filter: QDTO_expert,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    let query: any = {};
    if (filter.is_filter && filter.is_filter === 'true') {
      query = filter;
      delete query.is_filter;
    } else {
      if (this.ctx.user) {
        query = await this.service.dealQueryCondition(filter);
        delete query.is_filter;
      } else {
        query = filter;
        delete query.is_filter;
      }
    }
    const list = await this.service.query(query, {
      skip,
      limit,
      sort: { 'meta.createdAt': -1 },
    });
    const data = [];
    for (const i of list) {
      const newData = new QVO_expert(i);
      data.push(newData);
    }
    const total = await this.service.count(query);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_expert })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_expert(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_expert })
  async update(@Param('id') id: string, @Body() body: UDTO_expert) {
    // 检查手机号和上级id
    // await this.userUtil.checkUpdateCardAndPid(id, body);
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
