import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import {
  BaseService,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { Channel } from '../../entity/channel/channel.entity';
import { LoginDTO } from '../../interface/channel/channel.interface';
import isEqual = require('lodash/isEqual');
type modelType = ReturnModelType<typeof Channel>;
@Provide()
export class ChannelService extends BaseService<modelType> {
  @InjectEntityModel(Channel)
  model: modelType;

  async beforeCreate(body) {
    const last = await this.model.findOne().sort({ room_id: -1 });
    let room_id: any = '2001';
    if (last) room_id = parseInt(last.room_id) + 1;
    body.room_id = room_id;
    body.password = { secret: room_id.toString() };
    return body;
  }

  async findUserToLogin(data: LoginDTO): Promise<object> {
    const { room_id, password } = data;
    const user = await this.model.findOne({ room_id }, '+password').lean();
    if (!user)
      throw new ServiceError(
        `未找到展会号为: ${room_id} 的展会`,
        FrameworkErrorEnum.NOT_FOUND_DATA
      );
    if (!isEqual(user.password.secret, password))
      throw new ServiceError('密码错误', FrameworkErrorEnum.SERVICE_FAULT);
    return user;
  }
}
