import { Inject, Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Role } from '../../entity/system/role.entity';
import { Menus } from '../../entity/system/menus.entity';
import { AchieveExpert } from '../../entityAchieve/achieveExpert.entity';
import { MenusService } from './menus.service';
import get = require('lodash/get');
import flattenDeep = require('lodash/flattenDeep');
import uniq = require('lodash/uniq');
import groupBy = require('lodash/groupBy');

type modelType = ReturnModelType<typeof Role>;
@Provide()
export class RoleService extends BaseService<modelType> {
  @InjectEntityModel(Role)
  model: modelType;

  @InjectEntityModel(Menus)
  menusModel: ReturnModelType<typeof Menus>;

  @InjectEntityModel(AchieveExpert)
  achieveModel: ReturnModelType<typeof AchieveExpert>;

  @Inject()
  menusService: MenusService;

  async achieveInfo(user_id): Promise<object> {
    const info = await this.achieveModel.findById(user_id).lean();
    return info;
  }
  /**
   * 根据角色id数组,整理菜单
   * @param roleIdList 角色id数组
   */
  async getMenuByRoles(roleIdList) {
    const roleList = await this.model.find({ _id: roleIdList }).lean();
    let menus = [];
    // 第一步,整理所有菜单至一维数组
    for (const r of roleList) {
      const rm = get(r, 'menu', []);
      menus.push(...flattenDeep(rm));
    }
    menus = uniq(menus);
    const allMenu = await this.menusModel
      .find({ _id: menus }, { meta: 0, __v: 0 }, { sort: { sort: 1 } })
      .lean();
    const groupMenus = groupBy(allMenu, 'module_id');
    const resetMenu = {};
    for (const m in groupMenus) {
      const mAllMenu = groupMenus[m];
      let treeMenu = mAllMenu.filter(f => !f.parent_id);
      treeMenu = this.menusService.treeMenu(mAllMenu, treeMenu);
      resetMenu[m] = treeMenu;
    }
    return resetMenu;
  }
}
